@@ -38,6 +38,7 @@ _, have_h5py, _ = optional_package('h5py')
 
 from .. import (AnalyzeImage, Spm99AnalyzeImage, Spm2AnalyzeImage,
                 Nifti1Pair, Nifti1Image, Nifti2Pair, Nifti2Image,
+                GiftiImage,
                 MGHImage, Minc1Image, Minc2Image, is_proxy)
 from ..spatialimages import SpatialImage
 from .. import minc1, minc2, parrec, brikhead
@@ -493,6 +494,67 @@ class AffineMixin(object):
             assert_true(aff is img.get_affine())
 
 
+class SerializeMixin(object):
+    def validate_to_bytes(self, imaker, params):
+        img = imaker()
+        serialized = img.to_bytes()
+        with InTemporaryDirectory():
+            fname = 'img' + self.standard_extension
+            img.to_filename(fname)
+            with open(fname, 'rb') as fobj:
+                file_contents = fobj.read()
+        assert serialized == file_contents
+
+    def validate_from_bytes(self, imaker, params):
+        img = imaker()
+        klass = getattr(self, 'klass', img.__class__)
+        with InTemporaryDirectory():
+            fname = 'img' + self.standard_extension
+            img.to_filename(fname)
+
+            all_images = list(getattr(self, 'example_images', [])) + [{'fname': fname}]
+            for img_params in all_images:
+                img_a = klass.from_filename(img_params['fname'])
+                with open(img_params['fname'], 'rb') as fobj:
+                    img_b = klass.from_bytes(fobj.read())
+
+                assert self._header_eq(img_a.header, img_b.header)
+                assert np.array_equal(img_a.get_data(), img_b.get_data())
+                del img_a
+                del img_b
+
+    def validate_to_from_bytes(self, imaker, params):
+        img = imaker()
+        klass = getattr(self, 'klass', img.__class__)
+        with InTemporaryDirectory():
+            fname = 'img' + self.standard_extension
+            img.to_filename(fname)
+
+            all_images = list(getattr(self, 'example_images', [])) + [{'fname': fname}]
+            for img_params in all_images:
+                img_a = klass.from_filename(img_params['fname'])
+                bytes_a = img_a.to_bytes()
+
+                img_b = klass.from_bytes(bytes_a)
+
+                assert img_b.to_bytes() == bytes_a
+                assert self._header_eq(img_a.header, img_b.header)
+                assert np.array_equal(img_a.get_data(), img_b.get_data())
+                del img_a
+                del img_b
+
+    @staticmethod
+    def _header_eq(header_a, header_b):
+        """ Header equality check that can be overridden by a subclass of this test
+
+        This allows us to retain the same tests above when testing an image that uses an
+        abstract class as a header, namely when testing the FileBasedImage API, which
+        raises a NotImplementedError for __eq__
+        """
+        return header_a == header_b
+
+
+
 class LoadImageAPI(GenericImageAPI,
                    DataInterfaceMixin,
                    AffineMixin,
@@ -613,7 +675,7 @@ class TestNifti1PairAPI(TestSpm99AnalyzeAPI):
     can_save = True
 
 
-class TestNifti1API(TestNifti1PairAPI):
+class TestNifti1API(TestNifti1PairAPI, SerializeMixin):
     klass = image_maker = Nifti1Image
     standard_extension = '.nii'
 
@@ -660,7 +722,7 @@ class TestPARRECAPI(LoadImageAPI):
 #    standard_extension = '.v'
 
 
-class TestMGHAPI(ImageHeaderAPI):
+class TestMGHAPI(ImageHeaderAPI, SerializeMixin):
     klass = image_maker = MGHImage
     example_shapes = ((2, 3, 4), (2, 3, 4, 5))  # MGH can only do >= 3D
     has_scaling = True
@@ -668,6 +730,12 @@ class TestMGHAPI(ImageHeaderAPI):
     standard_extension = '.mgh'
 
 
+class TestGiftiAPI(LoadImageAPI, SerializeMixin):
+    klass = image_maker = GiftiImage
+    can_save = True
+    standard_extension = '.gii'
+
+
 class TestAFNIAPI(LoadImageAPI):
     loader = brikhead.load
     klass = image_maker = brikhead.AFNIImage
